#include "owndef.h"
#include "lcd.h"

// alle angegeben Zeiten gelten fr eine Taktfrequenz von 8MHZ

// ************************************************************************************************
// funktion zur initialisierung des lcd
// ************************************************************************************************
void LCD_Init(void)
{
  wait(25000); //ca 18ms
  wait(10);
  P1OUT=0x38;                         // System set,8 bit operation, 2-zeilen-display, 5*8 dot font
  BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // Befehl ausfuehren
  
  wait(7000);   //ca 5ms
  P1OUT=0x38;                         // System set,8 bit operation, 2-zeilen-display, 5*8 dot font
  //BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // Befehl ausfuehren
  
  wait(150);  //ca 110us
  P1OUT=0x38;                         // System set,8 bit operation, 2-zeilen-display, 5*8 dot font
  //BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // Befehl ausfuehren
  
  wait(150);  //ca 110us
  P1OUT=0x38;                         // System set,8 bit operation, 2-zeilen-display, 5*8 dot font
  //BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // Befehl ausfuehren
  
  wait(150);
  P1OUT=0x0C;                         // Display on/off, cursor aus, cursor blinkt nicht
  BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // befehl ausfuehren
  
  wait(150);
  P1OUT=0x06;                         // Entry modes set, Cursorrichtung: nach rechts; kein display-shift
  BitLoeschen(2,RS);                  // Instruction Mode
  LCD_Clock();                        // befehl ausfuehren
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zur loeschung des lcd-inhaltes
// ************************************************************************************************
void LCD_Clear(void)
{ 
  P1OUT = 0x01;                       // clear display
  BitLoeschen(2, RS);                 // Befehlsregister auswhlen
  //wait(150);  
  LCD_Clock();                        // befehl ausfuehren
  wait(5000);                         // clear display braucht was laenger
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zur befehlsuebernahme des lcd's
// ************************************************************************************************
void LCD_Clock(void) // E-Funktion  mit wait(40) --> 100us Periodendauer (fr Initialisierung eventuell auf 100 erhhen)
{
  wait(40);
  BitSetzen(2, E);
  wait(40);
  BitLoeschen(2, E);                  //Befehlsbernahme bei fallender E-Flanke
  wait(40);
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zum setzen des cursors
// der funktion werden die zeile- und spaltennummer uebergeben
// ************************************************************************************************
void LCD_Cursor_Set (BYTE Zeile, BYTE Spalte)	    	
{						   
        BitLoeschen(2, RS);           // LCD Instruction Mode
        
        if (Zeile == 0)		      // Ist die Zeile 0 (die Erste)?
  	{
          P1OUT = 0x80 + Spalte;      // 0x80 ist die Adresse der Zeile 0 und Spalte 0.
	}
	
  	if (Zeile == 1)		      // Ist die Zeile 1 (die Zweite)?
  	{
	  P1OUT = 0xC0 + Spalte;      // 0xC0 ist die Adresse der Zeile 1 und Spalte 0.
	}
		
	LCD_Clock();                        
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zum schreiben eines zeichens in das lcd
// der funktion wird ein zeichen uebergeben
// ************************************************************************************************
void LCD_Write (BYTE c)    	                 
{
  BitSetzen(2, RS);		      // LCD Data Mode
  P1OUT = c;                          // Port 0 sendet das Zeichen, das in der Variable c steht.
  LCD_Clock ();			      // Zeichenbernahme
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zum schreiben einer zeichenkette in das lcd
// der funktion wird ein zeichen-feld uebergeben
// ************************************************************************************************
void LCD_Awrite (BYTE c[])		           
{
  	int i;                        // Variable zur Numerierung der Zeichen im Feld

  	for (i=0; c[i]; i++)	      // In der For-Schleife wird fr die Anzahl der Zeichen
  	{  			      // die Funktion LCD_Write(BYTE) aufgerufen.
		LCD_Write(c[i]);      // Die Funktion LCD_Write(BYTE) stellt ein einzelnes
  	}			      // Zeichen im LCD dar.
}																																																	//
// ************************************************************************************************
// ************************************************************************************************
// funktion zur darstellung von zahlen im lcd
// der funktion wird die zahl, die gesamte anzahl an ziffern (inkl. nachkomma) und die anzahl der
// nachkommastellen uebergeben
// z.B.: LCD_Zahl(1234,4,2); gibt die Zahl 12.34 auf dem Display aus.
// ************************************************************************************************
void LCD_Zahl(WORD zahl, BYTE laenge, BYTE nachkomma)
{
        // Variablendeklarationen
  	BYTE wert = 0, nk = nachkomma;
  	BYTE string [11]="0000000000";              // maximal 10 Werte + Nullterminierung
	
	//if (Nachkomma != 0) ...
	if (nachkomma) wert = laenge + 1;           // Bestimmung des Endwertes
	else wert = laenge;
	
	string [wert] = 0;                          // setzenn der Null
	
	// Nachkommastellen ausgeben
	for (;nk;nk--)                
	{
	  string[--wert] = (zahl%10) + 0x30;        // Rest abspalten (Zahl + 0x30 = ASCII Wert)
	  zahl = zahl / 10;                         // Niederwertigste Stelle entfernen
	}
	
	if (nachkomma) string[--wert]='.';          // falls gewnscht, Komma ausgeben
	
	
	// Ganze Zahlen ausgeben
	for (laenge = laenge - nachkomma ;laenge;laenge--)
	{
	  string[--wert] = (zahl%10) + 0x30;
	  zahl = zahl / 10;
	}
	
	LCD_Awrite(string);                         // String an Displayfunktion ausgeben
}
// ************************************************************************************************
// ************************************************************************************************
// funktion zur darstellung von zaheln im lcd_2
// der funktion wird ein int zwischen 1 und 9999 uebergeben
// z.B.: LCD_Zahl2(1234); gibt die Zahl 1234 auf dem Display aus.
// ************************************************************************************************
void LCD_Zahl2(WORD z)
{                                         
  int t_einer,t_zehner,t_hunderter,t_tausender;

  t_einer = (z % 10) + 0x30;
  z = z/10;
  t_zehner = (z % 10) + 0x30;
  z = z / 10;
  t_hunderter = (z % 10) + 0x30;
  z = z / 10;
  t_tausender = (z % 10) + 0x30;
  LCD_Write ( t_tausender );
  //LCD_Write ( '.' );
  LCD_Write ( t_hunderter );
  LCD_Write ( t_zehner );
  LCD_Write ( t_einer );
}
// ************************************************************************************************
