#ifndef OWNDEF_H
#define OWNDEF_H

#define MCUTYPE 1612                                // mcu-typ

#if     MCUTYPE == 1612
 #include <msp430x16x.h>
#endif

// Prprozessor-Anweisungen
#define BitLoeschen(Port, Bit)   P ## Port ## OUT &= ~(Bit)
#define BitSetzen(Port, Bit)     P ## Port ## OUT |= (Bit)
#define BitToggeln(Port, Bit)    P ## Port ## OUT ^= (Bit)

//eigene datentypen
#define BYTE unsigned char                          // 8-Bit
#define WORD unsigned short                         // 16-Bit
#define DWORD unsigned long                         // 32-Bit
#define QWORD unsigned long long                    // 64-bit

// LCD (port2)
#define E               0x10                        // P 2.4 - Enable Signal fr LC-Display
#define RS              0x20                        // P 2.5 - RS des LCD

//*****************************
// meine eigenen defines
//*****************************
// port2
// leds
#define LED_SD       0x01                           // P2.0 led sd-card-protokoll aktiv
#define LED_LINE     0x02                           // P2.1 led line-mode aktiv
#define LED_MIC      0x04                           // P2.2 led mic-mode aktiv
#define LED_UEBER95  0x08                           // P2.3 led pegel > 95dB
#define LED_UEBER99  0x40                           // P2.6 led pegel > 99dB

// port3
// taster, peak-reset, spi
#define PEAK_RESET  0x01                            // P3.0 peak-schaltkreis zurcksetzten
#define SPI_DATA    0x02                            // P3.1 SPI data
#define SPI_CS      0x04                            // P3.2 SPI chip select
#define SPI_CLOCK   0x08                            // P3.3 SPI clock
#define UP          0x10                            // P3.4 taster up
#define LEFT        0x20                            // P3.5 taster left
#define SET         0x40                            // P3.6 taster set
#define RIGHT       0x80                            // P3.7 taster right

// port4
// taster, steuersignale
#define DOWN    0x01                                // P4.0 taster down
#define PGA     0x40                                // P4.6 taster PGA
#define LED_PGA 0x80                                // P4.7 led pga < 0dB; pga dmpft

#define STSIG_1  0x02                               // P4.1 steuersignal fuer line/ rauschen
#define STSIG_2  0x04                               // P4.2 steuersignal fuer line(bzw. rauschen)/
                                                    // mic-mode
#define STSIG_3  0x08                               // P4.3 steuersignal fuer a-bewertung
#define STSIG_4  0x10                               // P4.4 steuersignal fuer b-bewertung
#define STSIG_5  0x20                               // P4.5 steuersignal fuer c-bwertung

// port5
// statuspins fr sd-card
#define SW1     0x80                                // P5.7
#define SW3     0x20                                // P5.5
#define SW2     0x40                                // P5.6

#define MINIMALLAUTSTAERKE  7000                    // minimaler wert fr pegel (--> 70dB)
#define MAXIMALLAUTSTAERKE 13000                    // maximaler wert fr pegel (--> 130dB)

#define MAXIMALKORREKTUR    3000                    // max. einstellbarer korrekturwert (--> 30dB)

#define ENTPRELLZAHL        1                       // schleifendurchlufe fr tastenentprellung

#define ZEITBASIS          ((32768/8)-1)                // tick-zhler bis zum nchsten messwert

#define PGA_WERT_MIN        1                       // minimaler wert des PGA's (1 = -95.5dB)
#define PGA_WERT_MAX        255                     // minimaler wert des PGA's (255 = 31.5dB)
#define PGA_WERT_0dB        192                     // pga-wert, bei dem eine verstaerkung von 0dB
                                                    // erreicht ist (1 = -95.5dB; 255 = 31.5dB)
#define PGA_DEKREMENT       2                       // schritte beim runterregeln
#define PGA_INKREMENT       1                       // schritte beim hochregeln
#define PGA_INKREMENT_TASTE 1                       // schritte beim hochregeln per taster 6                                                

#define WANDLERWERT_EFF_O   3695
#define WANDLERWERT_EFF_U   176
#define WANLDERWERT_PEAK_O  3950
#define WANDLERWERT_PEAK_U  210
//#define EFF_ANSTIEG         0.0185                  // berechneter wert aus den ad-werten
//#define EFF_Y_SCHNITT       66.75                   // berechneter wert aus den ad-werten
//#define PEAK_ANSTIEG        0.0174                  // berechneter wert aus den ad-werten
//#define PEAK_Y_SCHNITT      66.35                   // berechneter wert aus den ad-werten

// sonderezeichen fuers display
#define PFEILRECHTS    126                          // sonderzeichen pfeil nach rechts     
#define PFEILLINKS     127                          // sonderzeichen pfeil nach links
#define BUCHSTABE_AE   225                          // sonderzeichen 
#define BUCHSTABE_OE   239                          // sonderzeichen 
#define BUCHSTABE_UE   245                          // sonderzeichen 
#define BUCHSTABE_mue  228                          // sonderzeichen 

#endif
